@@ -2,7 +2,7 @@
 
 from typing import Type
 
-from gpt_index.data_structs import IndexStructType
+from gpt_index.data_structs.struct_type import IndexStructType
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.keyword_table.query import (
     GPTKeywordTableGPTQuery,
@@ -18,7 +18,7 @@ from gpt_index.indices.query.tree.retrieve_query import GPTTreeIndexRetQuery
 from gpt_index.indices.query.tree.summarize_query import GPTTreeIndexSummarizeQuery
 from gpt_index.indices.query.vector_store.faiss import GPTFaissIndexQuery
 from gpt_index.indices.query.vector_store.simple import GPTSimpleVectorIndexQuery
-from gpt_index.indices.query.vector_store.weaviate import GPTWewaviateIndexQuery
+from gpt_index.indices.query.vector_store.weaviate import GPTWeaviateIndexQuery
 
 MODE_TO_QUERY_MAP_TREE = {
     QueryMode.DEFAULT: GPTTreeIndexLeafQuery,
@@ -49,7 +49,7 @@ MODE_TO_QUERY_MAP_SIMPLE = {
 }
 
 MODE_TO_QUERY_MAP_WEAVIATE = {
-    QueryMode.DEFAULT: GPTWewaviateIndexQuery,
+    QueryMode.DEFAULT: GPTWeaviateIndexQuery,
 }
 
 
