@@ -1,16 +1,9 @@
 """Retrieve query."""
 
-from typing import Any, Optional
-
-from gpt_index.data_structs import IndexGraph
+from gpt_index.data_structs.data_structs import IndexGraph
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.response.builder import ResponseBuilder, TextChunk
 from gpt_index.indices.utils import get_sorted_node_list
-from gpt_index.prompts.default_prompts import (
-    DEFAULT_REFINE_PROMPT,
-    DEFAULT_TEXT_QA_PROMPT,
-)
-from gpt_index.prompts.prompts import QuestionAnswerPrompt, RefinePrompt
 
 
 class GPTTreeIndexRetQuery(BaseGPTIndexQuery[IndexGraph]):
@@ -32,18 +25,6 @@ class GPTTreeIndexRetQuery(BaseGPTIndexQuery[IndexGraph]):
 
     """
 
-    def __init__(
-        self,
-        index_struct: IndexGraph,
-        text_qa_template: Optional[QuestionAnswerPrompt] = None,
-        refine_template: Optional[RefinePrompt] = None,
-        **kwargs: Any,
-    ) -> None:
-        """Initialize params."""
-        super().__init__(index_struct, **kwargs)
-        self.text_qa_template = text_qa_template or DEFAULT_TEXT_QA_PROMPT
-        self.refine_template = refine_template or DEFAULT_REFINE_PROMPT
-
     def _query(self, query_str: str, verbose: bool = False) -> str:
         """Answer a query."""
         print(f"> Starting query: {query_str}")
