@@ -10,6 +10,7 @@ definition of a Document - the bare minimum is a `text` property.
 
 """
 
+from gpt_index.readers.discord_reader import DiscordReader
 from gpt_index.readers.faiss import FaissReader
 
 # readers
@@ -29,6 +30,7 @@ __all__ = [
     "SimpleMongoReader",
     "NotionPageReader",
     "GoogleDocsReader",
+    "DiscordReader",
     "SlackReader",
     "WeaviateReader",
     "PineconeReader",
