@@ -1,8 +1,8 @@
-"""Simple reader that ."""
+"""Simple reader that reads wikipedia."""
 from typing import Any, List
 
 from gpt_index.readers.base import BaseReader
-from gpt_index.schema import Document
+from gpt_index.readers.schema.base import Document
 
 
 class WikipediaReader(BaseReader):
@@ -22,7 +22,12 @@ class WikipediaReader(BaseReader):
             )
 
     def load_data(self, **load_kwargs: Any) -> List[Document]:
-        """Load data from the input directory."""
+        """Load data from the input directory.
+
+        Args:
+            pages (List[str]): List of pages to read.
+
+        """
         import wikipedia
 
         pages: List[str] = load_kwargs.pop("pages", None)
